@@ -371,7 +371,7 @@ class SchemaType(object):
         raise AssertionError("Can't call 'set_value' on a leaf node.")
 
     def get_value(self, node, appstruct, path):
-        raise AssertionError("Can't call 'set_value' on a leaf node.")
+        raise AssertionError("Can't call 'get_value' on a leaf node.")
 
 class Mapping(SchemaType):
     """ A type which represents a mapping of names to nodes.
@@ -901,7 +901,7 @@ class String(SchemaType):
         self.encoding = encoding
 
     def serialize(self, node, appstruct):
-        if appstruct is null:
+        if not appstruct:
             return null
 
         try:
@@ -1188,11 +1188,12 @@ class DateTime(SchemaType):
     datetime.
 
     The constructor accepts an argument named ``default_tzinfo`` which
-    should be a Python ``tzinfo`` object; by default it is None,
-    meaning that the default tzinfo will be equivalent to UTC (Zulu
-    time).  The ``default_tzinfo`` tzinfo object is used to convert
-    'naive' datetimes to a timezone-aware representation during
-    serialization.
+    should be a Python ``tzinfo`` object. If ``default_tzinfo`` is not
+    specified the default tzinfo will be equivalent to UTC (Zulu time).
+    The ``default_tzinfo`` tzinfo object is used to convert 'naive'
+    datetimes to a timezone-aware representation during serialization.
+    If ``default_tzinfo`` is explicitly set to ``None`` then no default
+    tzinfo will be applied to naive datetimes.
 
     You can adjust the error message reported by this class by
     changing its ``err_template`` attribute in a subclass on an
@@ -1231,7 +1232,7 @@ class DateTime(SchemaType):
         self.default_tzinfo = default_tzinfo
 
     def serialize(self, node, appstruct):
-        if appstruct is null:
+        if not appstruct:
             return null
 
         if type(appstruct) is datetime.date: # cant use isinstance; dt subs date
@@ -1307,7 +1308,7 @@ class Date(SchemaType):
     err_template =  _('Invalid date')
 
     def serialize(self, node, appstruct):
-        if appstruct is null:
+        if not appstruct:
             return null
 
         if isinstance(appstruct, datetime.datetime):
@@ -1383,7 +1384,7 @@ class Time(SchemaType):
     err_template =  _('Invalid time')
 
     def serialize(self, node, appstruct):
-        if appstruct is null:
+        if not appstruct:
             return null
 
         if isinstance(appstruct, datetime.datetime):
