@@ -1078,6 +1078,14 @@ class TestString(unittest.TestCase):
         result = typ.serialize(node, null)
         self.assertEqual(result, null)
 
+    def test_serialize_none(self):
+        import colander
+        val = None
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.serialize(node, val)
+        self.assertEqual(result, colander.null)
+
     def test_serialize_uncooperative(self):
         val = Uncooperative()
         node = DummySchemaNode(None)
@@ -1523,11 +1531,15 @@ class TestDateTime(unittest.TestCase):
         import datetime
         return datetime.date.today()
 
-    def test_ctor_default_tzinfo_None(self):
+    def test_ctor_default_tzinfo_not_specified(self):
         from .. import iso8601
         typ = self._makeOne()
         self.assertEqual(typ.default_tzinfo.__class__, iso8601.Utc)
 
+    def test_ctor_default_tzinfo_None(self):
+        typ = self._makeOne(default_tzinfo=None)
+        self.assertEqual(typ.default_tzinfo, None)
+
     def test_ctor_default_tzinfo_non_None(self):
         from .. import iso8601
         tzinfo = iso8601.FixedOffset(1, 0, 'myname')
@@ -1542,6 +1554,14 @@ class TestDateTime(unittest.TestCase):
         result = typ.serialize(node, val)
         self.assertEqual(result, colander.null)
 
+    def test_serialize_none(self):
+        import colander
+        val = None
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.serialize(node, val)
+        self.assertEqual(result, colander.null)
+
     def test_serialize_with_garbage(self):
         typ = self._makeOne()
         node = DummySchemaNode(None)
@@ -1647,6 +1667,7 @@ class TestDateTime(unittest.TestCase):
         node = DummySchemaNode(None)
         result = typ.deserialize(node, iso)
         self.assertEqual(result.isoformat(), dt.isoformat())
+        self.assertEqual(result.tzinfo, None)
 
 class TestDate(unittest.TestCase):
     def _makeOne(self, *arg, **kw):
@@ -1669,6 +1690,14 @@ class TestDate(unittest.TestCase):
         result = typ.serialize(node, val)
         self.assertEqual(result, colander.null)
 
+    def test_serialize_none(self):
+        import colander
+        val = None
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.serialize(node, val)
+        self.assertEqual(result, colander.null)
+
     def test_serialize_with_garbage(self):
         typ = self._makeOne()
         node = DummySchemaNode(None)
@@ -1754,6 +1783,14 @@ class TestTime(unittest.TestCase):
         result = typ.serialize(node, val)
         self.assertEqual(result, colander.null)
 
+    def test_serialize_none(self):
+        import colander
+        val = None
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.serialize(node, val)
+        self.assertEqual(result, colander.null)
+
     def test_serialize_with_garbage(self):
         typ = self._makeOne()
         node = DummySchemaNode(None)
